pub struct NewWorkerMetadata {
pub service_id: i32,
pub last_dispatched_task_id: i64,
pub last_returned_task_id: Option<i64>,
pub total_dispatched: i32,
pub total_returned: i32,
pub first_seen: SystemTime,
pub session_seen: Option<SystemTime>,
pub time_last_dispatch: SystemTime,
pub time_last_return: Option<SystemTime>,
pub name: String,
}Expand description
Metadata collection for workers, updated by the dispatcher upon zmq transactions
Fields
service_id: i32associated service for this worker metadata set
last_dispatched_task_id: i64time of last ventilator dispatch to the service
last_returned_task_id: Option<i64>time of last sink job received from the service
total_dispatched: i32dispatch totals
total_returned: i32return totals
first_seen: SystemTimefirst registered ventilator request for this worker, coincides with insertion in DB
session_seen: Option<SystemTime>first time seen in the current dispatcher session
time_last_dispatch: SystemTimetime of last dispatched task
time_last_return: Option<SystemTime>time of last returned job result
name: Stringidentity of this worker, usually hostname:pid